<?php
/*
Plugin Name: BlogBlogs User Info
Plugin URI: http://www.rafaeldohms.com.br/dmsdev/index.php?go=projView&prj=69
Description: This plugin fetches information from BlogBlogs for every user who comments on your blog, if that user has an account at BlogBlogs.com.br, his info (pic, blogs, etc...) is show inside the comment window
Author: Rafael Dohms
Version: 0.85 beta
Author URI: http://www.rafaeldohms.com.br/

@version $Id: bbuinfo.php 140 2007-07-07 15:04:15Z Dooms $
*/

$bbUInfo = array();

/**
 * Executada ao instalar o script.
 * Cria no banco as opes do plugin
 */
function bbUI_install(){
	global $wpdb;

	//Adicionar campos de opes
	add_option('bbuinfo_APIKEY','','BlogBlogs APIKEY para o UserInfo Plugin');
	add_option('bbuinfo_method','JS','Modo de resgate de dados para o UserInfo Plugin');
	add_option('bbuinfo_cacheTime','120','Tempo de vida do cache em minutos do bbUinfo');

	//Criar base de dados de cache
	$create = $wpdb->query("
		CREATE TABLE IF NOT EXISTS bbuinfo_cache (
  			usremail VARCHAR(60) NOT NULL,
  			xmldata TEXT NULL,
  			cachedon DATETIME NULL,
  		PRIMARY KEY(usremail));
	");
	
}

/**
 * Inicializa o script, buscando as opes e preparando a base
 *
 */
function bbUI_init(){
	global $bbUInfo;

	$blogUrl = get_option('siteurl');

	$bbUInfo['perfil'] = "";
	$bbUInfo['blogUrl'] = $blogUrl;
	$bbUInfo['plugin_path'] = $bbUInfo['blogUrl']."/wp-content/plugins/".dirname(plugin_basename(__FILE__));
	$bbUInfo['plugin_fpath'] = dirname(__FILE__);
	$bbUInfo['url'] = "http://api.blogblogs.com.br/api/rest/userinfo";
	$bbUInfo['proxy'] = $blogUrl."/wp-content/plugins/bbuinfo/bbuinfo-proxy.php";
	$bbUInfo['APIKEY'] = get_option('bbuinfo_APIKEY');
	$bbUInfo['method'] = get_option('bbuinfo_method'); // JS|PHP

	//Adicionar hook para incluir arquivo javascript
	if ($bbUInfo['method'] == 'JS'){
		add_action('wp_print_scripts','bbUI_loadJS');
	}

	//Adicionar CSS
	add_action('wp_print_scripts','bbUI_loadCSS');

}

/**
 * Adiciona ao WP a pagina de gerenciamento das opcoes
 */
function bbUI_loadmenu(){
	add_options_page('BBUinfo - Gerenciamento','BBUinfo',10,__FILE__,'bbUI_exec_options');
}

/**
 * Mostra pagina de gerencia e executa a gravacao dos dados
 */
function bbUI_exec_options(){
	global $bbUInfo;
	$errors = array();

	if (count($_POST) > 0){
		//Validar e gravar opes
		if ($_POST['bbuinfo_APIKEY'] != ''){
			update_option('bbuinfo_APIKEY',$_POST['bbuinfo_APIKEY']);
		}else{
			$errors[] = "A APIKEY  obrigatria para o uso do plugin.";
		}

		if ($_POST['bbuinfo_method'] != ''){
			update_option('bbuinfo_method',$_POST['bbuinfo_method']);
		}else{
			$errors[] = "Escolha um modo de obter os dados.";
		}

	}

	//Pegar template
	//Usando funes do WP
	$admTplObj = new FileReader($bbUInfo['plugin_fpath']."/admin_tpl.htm");
	$admTpl = $admTplObj->read($admTplObj->_length);

	//Atribuir valores
	$admTpl = str_replace("{bbuinfo_APIKEY}",get_option('bbuinfo_APIKEY'),$admTpl);
	if (get_option('bbuinfo_method') == 'JS'){
		$admTpl = str_replace('{js_check}','checked="checked"',$admTpl);
		$admTpl = str_replace('{php_check}','',$admTpl);
	}else{
		$admTpl = str_replace('{js_check}','',$admTpl);
		$admTpl = str_replace('{php_check}','checked',$admTpl);
	}
	if (count($errors) > 0){
		$admTpl = str_replace('{ERROS}','<p id="">'.implode('<br>',$errors).'</p>',$admTpl);
	}else{
		$admTpl = str_replace('{ERROS}','',$admTpl);
	}
	echo $admTpl;
}

//Funao que resgata dados
/**
 * Pega o email do comentrio e convoca a obtencao de dados
 *
 * @param int $comment_ID cdigo do comentario
 * @return int ID do comentrio
 */
function bbUI_workCmt($comment_ID) {
	global $bbUInfo, $wpdb;

	//Habilitar filtro que ira mostrar dados (SELF HOOK)
	add_filter('get_comment_text', 'bbUI_showInfo');

	//Buscar email do author
	$auth_email = $wpdb->get_var("SELECT comment_author_email FROM `$wpdb->comments` WHERE `comment_ID` = '$comment_ID'");

	//Disable next filter if no email found
	if ($auth_email == ''){
		remove_filter('get_comment_text', 'bbUI_showInfo');
		$bbUInfo['debug'] = "Erro ao pegar email do comentrio";
		//add_filter('get_comment_text', 'bbUI_debug');
	}else{

		if ($bbUInfo['method'] == 'PHP'){
			//Rodar funo que busca por PHP
			$bbUInfo['perfil'] = bbUI_phpGetInfo($auth_email);
		}else{
			//Rodar JS
			$js  = '<div id="bbuinfo_container_'.$comment_ID.'">';
			$js .= '<script type="text/javascript" id="bbuinfo_cmt_'.$comment_ID.'">';
			$js .= '  BB_key = "'.$bbUInfo['APIKEY'].'";';
			$js .= '  BB_url = "'.$bbUInfo['url'].'";';
			$js .= '  BB_proxy = "'.$bbUInfo['proxy'].'";';
			$js .= '  BB_uniqueID = "'.$comment_ID.'";';
			$js .= '  var BBAPI_'.$comment_ID.' = new BBAPI("'.$auth_email.'");';
			$js .= '</script>';
			$js .= '</div>';

			$bbUInfo['perfil'] = $js;
		}

	}
	//Retornar ID recebido para no quebrar outros plug-ins
	return  $comment_ID;
}

/**
 * Conecta no BlogBlogs e resgata o cdigo do XML
 *
 * @param string $url URL da API
 * @return string XML source
 */
function bbUI_getXML($url){
	global $bbUInfo;

	if (ini_get("allow_url_fopen")){
		return file_get_contents($url);
	}else{
		//FSCKOPEN or FOPEN Wrappers
		require_once( ABSPATH . 'wp-includes/class-snoopy.php');//Obtida pelo WP
		
		$sn = new Snoopy();
		$sn->fetch($url);
		$xml = $sn->results;
		unset($sn);
		return $xml;
	}
}

/**
 * Chama a busca de dados e monta o template
 *
 * @param string $auth_email email do autor
 * @return string HTML
 */
function bbUI_phpGetInfo($auth_email){
	global $bbUInfo,$comment_ID;

	//Buscar dados do BlogBlogs API
	$bbXmlString = bbUI_getXML($bbUInfo['proxy']."?url=".$bbUInfo['url']."&key=".$bbUInfo['APIKEY']."&email=".$auth_email);
	$bbXml = simplexml_load_string($bbXmlString);

	if (!$bbXml){
		//Erro ao conectar com BlogBlogs
		remove_filter('get_comment_text', 'bbUI_showInfo');
		$bbUInfo['debug'] = "Erro ao buscar no BlogBlogs";
		//add_filter('get_comment_text', 'bbUI_debug');
	}else{
		//Verificar se possui conta no BB
		if ($bbXml->document->result->error != ''){
			remove_filter('get_comment_text', 'bbUI_showInfo');
			$bbUInfo['debug'] = "Perfil BB no encontrado para este e-mail";
			//add_filter('get_comment_text', 'bbUI_debug');
		}else{
			//Tratar dados
			$rank = ($bbXml->document->item->weblog->rank > 0)? $bbXml->document->item->weblog->rank:"0";

			//Montar template
			$template .= '<div class="bb_user_info" id="bbui_div_'.$comment_ID.'">';
			$template .= ' <div style="display: block;" id="bbui_cnt_'.$comment_ID.'" align="center">';
			$template .= '   <table class="bbui_table" id="bbui_table_'.$comment_ID.'" align="center">';
			$template .= '     <tr>';
			$template .= '       <td class="bbui_img" rowspan="2"><a title="'.$bbXml->document->result->fullname.'" href="'.$bbXml->document->result->profilepage.'" id="link_img'.$comment_ID.'"><img src="'.$bbXml->document->result->thumbnailpicture.'" id="img'.$comment_ID.'"></a></td>';
			$template .= '       <td class="bbui_nome" colspan="4"><a title="'.$bbXml->document->result->fullname.'" href="'.$bbXml->document->result->profilepage.'" id="link_name'.$comment_ID.'">'.$bbXml->document->result->fullname.'</a></td>';
			$template .= '     </tr>';
			$template .= '     <tr>';
			$template .= '       <td class="bbui_blog"><a title="'.$bbXml->document->result->fullname.' tem $bbXml->document->result->blogs blogs" href="'.$bbXml->document->result->profilepage.'" id="link_blogs'.$comment_ID.'"><img src="http://assets5.blogblogs.com.br/public/bb/images/mini/page_world.png">'.$bbXml->document->result->blogs.' blogs</a></td>';
			$template .= '       <td class="bbui_rank"><a title="Rank do Blog" href="'.$bbXml->document->result->profilepage.'" id="link_rank'.$comment_ID.'"><img src="http://assets4.blogblogs.com.br/public/bb/images/mini/award_star_gold_1.png">'.$rank.'</a></td>';
			$template .= '       <td class="bbui_feed"><a title="'.$bbXml->document->result->favorites.' Favoritos" href="'.$bbXml->document->result->profilepage.'" id="link_feeds'.$comment_ID.'"><img src="http://assets2.blogblogs.com.br/public/bb/images/mini/heart_add.png">'.$bbXml->document->result->favorites.'</a></td>';
			$template .= '       <td class="bbui_fas"><a title="'.$bbXml->document->result->fullname.' tem '.$bbXml->document->result->fans.' f&atilde;ns" href="'.$bbXml->document->result->profilepage.'" id="link_fas'.$comment_ID.'"><img src="http://assets1.blogblogs.com.br/public/bb/images/mini/hearts.png">'.$bbXml->document->result->fans.'</a></td>';
			$template .= '     </tr>';
			$template .= '   </table>';
			$template .= ' </div>';
			$template .= '</div>';
			

			return $template;
		}
	}
}

/**
 * Mostra o perfil da pessoa junto ao comentario
 *
 * @param string $cnt comentario 
 * @return string html completo
 */
function bbUI_showInfo($cnt){
	global $bbUInfo;

	$cnt = $cnt.$bbUInfo['perfil'];
	$bbUInfo['perfil'] = '';

	return $cnt;
}

/**
 * Insere chamada ao script Javascript para chamadas AJAX
 */
function bbUI_loadJS(){
	global $bbUInfo;

	echo "<script type='text/javascript' src='".$bbUInfo['plugin_path']."/js/bbapi.js' ></script>";
}

/**
 * Insere estilos CSS
 */
function bbUI_loadCSS(){
	global $bbUInfo;

	//Carregar CSS
	$cssFile = new FileReader($bbUInfo['plugin_fpath']."/bbuinfo.css");
	$css = $cssFile->read($cssFile->_length);
	//Substituir path de imagens
	$css = str_replace(":PLUGIN_PATH:",$bbUInfo['plugin_path']."/",$css);
	echo $css;

}

/**
 * Debug function
 *
 * @param unknown_type $cnt
 * @return unknown
 */
function bbUI_debug($cnt){
	global $bbUInfo;

	$cnt .= "<br><br>";
	$cnt .= "Debug Ligado, info:<br>";
	$cnt .= $bbUInfo['debug'];
	//$cnt .= "<br><br>".implode("<br>",$bbUInfo['erros']);

	remove_filter('get_comment_text', 'bbUI_debug');
	$bbUInfo['debug'] = "";

	return $cnt;
}

/**
 *  Adicionar HOOKs do WordPress
 */

/** Funo de instalao */
register_activation_hook('bbuinfo/bbuinfo.php','bbUI_install');
/** Funo de inicializao */
add_filter('init', 'bbUI_init');
/** Funo uqe manipula comentario */
add_filter('get_comment_ID', 'bbUI_workCmt');
/** Funo que carrega o menu */
add_action('admin_menu','bbUI_loadmenu');


?>